@@ -1,5 +1,5 @@
-use basic_dsp::*;
 use basic_dsp::numbers::*;
+use basic_dsp::*;
 use std::boxed::Box;
 
 pub const DEFAULT_DATA_SIZE: usize = 10000;
@@ -12,17 +12,16 @@ pub type ComplexTime32Box = VectorBox<ComplexTimeVec<Vec<f32>, f32>, f32>;
 pub type Gen32Box = VectorBox<GenDspVec<Vec<f32>, f32>, f32>;
 
 pub struct VectorBox<B, T>
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     pub vector: *mut B,
+    pub argument: *mut B,
     pub size: usize,
     pub buffer: SingleBuffer<T>,
 }
 
-#[derive(Copy)]
-#[derive(Clone)]
-#[derive(PartialEq)]
-#[derive(Debug)]
+#[derive(Copy, Clone, PartialEq, Debug)]
 pub enum Size {
     Tiny,
     Small,
@@ -43,8 +42,10 @@ impl VectorBox<RealTimeVec<Vec<f32>, f32>, f32> {
     pub fn new(size: Size) -> VectorBox<RealTimeVec<Vec<f32>, f32>, f32> {
         let size = translate_size(size);
         let data = vec![10.0; size];
+        let argument = vec![10.0; size];
         VectorBox {
-            vector: Box::into_raw(Box::new(data.to_real_time_vec())),
+            vector:  Box::into_raw(Box::new(data.to_real_time_vec_par())),
+            argument:  Box::into_raw(Box::new(argument.to_real_time_vec_par())),
             buffer: SingleBuffer::with_capacity(size),
             size: size,
         }
@@ -55,8 +56,10 @@ impl VectorBox<Vec<f32>, f32> {
     pub fn new(size: Size) -> VectorBox<Vec<f32>, f32> {
         let size = translate_size(size);
         let data = vec![10.0; size];
+        let argument = vec![10.0; size];
         VectorBox {
             vector: Box::into_raw(Box::new(data)),
+            argument: Box::into_raw(Box::new(argument)),
             buffer: SingleBuffer::with_capacity(size),
             size: size,
         }
@@ -67,8 +70,10 @@ impl VectorBox<Vec<f64>, f64> {
     pub fn new(size: Size) -> VectorBox<Vec<f64>, f64> {
         let size = translate_size(size);
         let data = vec![10.0; size];
+        let argument = vec![10.0; size];
         VectorBox {
             vector: Box::into_raw(Box::new(data)),
+            argument: Box::into_raw(Box::new(argument)),
             buffer: SingleBuffer::with_capacity(size),
             size: size,
         }
@@ -83,8 +88,10 @@ impl VectorBox<GenDspVec<Vec<f32>, f32>, f32> {
 
     pub fn with_size(size: usize) -> VectorBox<GenDspVec<Vec<f32>, f32>, f32> {
         let data = vec![10.0; size];
+        let argument = vec![10.0; size];
         VectorBox {
-            vector: Box::into_raw(Box::new(data.to_gen_dsp_vec(true, DataDomain::Time))),
+            vector: Box::into_raw(Box::new(data.to_gen_dsp_vec_par(true, DataDomain::Time))),
+            argument: Box::into_raw(Box::new(argument.to_gen_dsp_vec_par(true, DataDomain::Time))),
             buffer: SingleBuffer::with_capacity(size),
             size: size,
         }
@@ -95,8 +102,10 @@ impl VectorBox<ComplexTimeVec<Vec<f32>, f32>, f32> {
     pub fn new(size: Size) -> VectorBox<ComplexTimeVec<Vec<f32>, f32>, f32> {
         let size = translate_size(size);
         let data = vec![10.0; size];
+        let argument = vec![10.0; size];
         VectorBox {
-            vector: Box::into_raw(Box::new(data.to_complex_time_vec())),
+            vector: Box::into_raw(Box::new(data.to_complex_time_vec_par())),
+            argument: Box::into_raw(Box::new(argument.to_complex_time_vec_par())),
             buffer: SingleBuffer::with_capacity(size),
             size: size,
         }
@@ -107,8 +116,10 @@ impl VectorBox<RealTimeVec<Vec<f64>, f64>, f64> {
     pub fn new(size: Size) -> VectorBox<RealTimeVec<Vec<f64>, f64>, f64> {
         let size = translate_size(size);
         let data = vec![10.0; size];
+        let argument = vec![10.0; size];
         VectorBox {
-            vector: Box::into_raw(Box::new(data.to_real_time_vec())),
+            vector: Box::into_raw(Box::new(data.to_real_time_vec_par())),
+            argument: Box::into_raw(Box::new(argument.to_real_time_vec_par())),
             buffer: SingleBuffer::with_capacity(size),
             size: size,
         }
@@ -117,14 +128,16 @@ impl VectorBox<RealTimeVec<Vec<f64>, f64>, f64> {
 
 #[allow(dead_code)]
 impl<B, T> VectorBox<B, T>
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     pub fn len(&self) -> usize {
         self.size
     }
 
     pub fn execute<F>(&mut self, function: F) -> bool
-        where F: Fn(B, &mut SingleBuffer<T>) -> B + 'static + Sync
+    where
+        F: Fn(B, &mut SingleBuffer<T>) -> B + 'static + Sync,
     {
         unsafe {
             let vector = Box::from_raw(self.vector);
@@ -134,10 +147,26 @@ impl<B, T> VectorBox<B, T>
 
         true
     }
+
+    pub fn execute_with_arg<F>(&mut self, function: F) -> bool
+        where
+            F: Fn(B, B, &mut SingleBuffer<T>) -> (B, B) + 'static + Sync
+    {
+        unsafe {
+            let vector = Box::from_raw(self.vector);
+            let argument = Box::from_raw(self.argument);
+            let (result, arg) = function(*vector, *argument, &mut self.buffer);
+            self.vector = Box::into_raw(Box::new(result));
+            self.argument = Box::into_raw(Box::new(arg));
+        }
+
+        true
+    }
 }
 
 impl<B, T> Drop for VectorBox<B, T>
-    where T: RealNumber
+where
+    T: RealNumber,
 {
     fn drop(&mut self) {
         unsafe {
